@@ -1,4 +1,5 @@
 from eloquentarduino.ml.data.preprocessing.pipeline.Pipeline import Pipeline
+from eloquentarduino.ml.data.preprocessing.pipeline.BoxCox import BoxCox
 from eloquentarduino.ml.data.preprocessing.pipeline.Diff import Diff
 from eloquentarduino.ml.data.preprocessing.pipeline.FFT import FFT
 from eloquentarduino.ml.data.preprocessing.pipeline.MinMaxScaler import MinMaxScaler
@@ -7,3 +8,4 @@ from eloquentarduino.ml.data.preprocessing.pipeline.PolynomialFeatures import Po
 from eloquentarduino.ml.data.preprocessing.pipeline.SelectKBest import SelectKBest
 from eloquentarduino.ml.data.preprocessing.pipeline.StandardScaler import StandardScaler
 from eloquentarduino.ml.data.preprocessing.pipeline.Window import Window
+from eloquentarduino.ml.data.preprocessing.pipeline.YeoJohnson import YeoJohnson
